# gaitutils

Gaitutils facilitates extracting and plotting gait data. It also includes some data processing functionality (e.g. automatic event detection). 

Gaitutils can work with Vicon Nexus and also read directly from .c3d files (if you install the btk package).

